/***************************************************************************
 *   Copyright (C) 2008, 2009 by Stephane List                             *
 *   slist@lilotux.net                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _QMOTION_H_
#define _QMOTION_H_

#include <QTimer>
#include <QColor>
#include <QImage>

#include "ui_qmotion.h"
#include "recordersetupdlg.h"

#include <cv.h>
#include <highgui.h>

class QMotion : public QMainWindow, private Ui::QMainWindowBase
{
	Q_OBJECT

	public:
		QMotion(QWidget *parent = 0);
		~QMotion();
 
	public slots:
    void captureLoop();
		void fps_update();

	private slots:
		void about();
		void motion_treatment();
		void dir_settings();
		void on_pushButton_color_clicked();
		void on_limit_fps_valueChanged(int limite);

	signals:
	    void motion();

	protected:
			void resizeEvent( QResizeEvent * event );

	private:
			static QImage Ipl2QImage(const IplImage *newImage,bool upsideDown);
			void  update_mhi(IplImage* img, IplImage* dst, int diff_threshold);
			void add_timestamp(QImage & img);
			CvCapture* capture_;
			QImage  qImage_;
			QImage  qMotion_;
			QTimer timer_;
			QTimer timer_fps_;
			QColor color_;

			IplImage* image_;
			IplImage* motion_;
			int counter_;
			int counter_last_;

			// ring image buffer
			IplImage **buf;
			int last;

			// temporary images
			IplImage *mhi; // MHI
			IplImage *orient; // orientation
			IplImage *mask; // valid orientation mask
			IplImage *red;
			IplImage *green; 
			IplImage *blue; 
			IplImage *segmask; // motion segmentation map
			CvMemStorage* storage; // temporary storage
};

#endif
